[−][src]Enum byte_slice_cast::Error
pub enum Error {
AlignmentMismatch {
dst_type: &'static str,
dst_minimum_alignment: usize,
},
LengthMismatch {
dst_type: &'static str,
src_slice_size: usize,
dst_type_size: usize,
},
CapacityMismatch {
dst_type: &'static str,
src_vec_capacity: usize,
dst_type_capacity: usize,
},
}Possible errors during slice conversion.
Variants
The input slice is not properly aligned for the
output data type. E.g. for an u32 output slice
the memory must be 4-byte aligned.
A non-integer number of values from the output type would be in the output slice.
When converting a Vec<T> it had a capacity that
allowed only for a non-integer number of values
from the output type.